@@ -9,7 +9,7 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.CloudWatchRUM 1.26.0\nVersion:         1.26.0.post1\nBuilder"
+        "Type annotations for boto3.CloudWatchRUM 1.26.12\nVersion:         1.26.12\nBuilder"
         " version: 7.11.10\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rum//\nBoto3 docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rum.html#CloudWatchRUM\nOther"
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.26.0.post1")
+    print("1.26.12")
 
 
 def main() -> None:
