@@ -32,6 +32,7 @@ from .type_defs import (
     BatchDeleteRumMetricDefinitionsResponseTypeDef,
     BatchGetRumMetricDefinitionsResponseTypeDef,
     CreateAppMonitorResponseTypeDef,
+    CustomEventsTypeDef,
     GetAppMonitorDataResponseTypeDef,
     GetAppMonitorResponseTypeDef,
     ListAppMonitorsResponseTypeDef,
@@ -160,6 +161,7 @@ class CloudWatchRUMClient(BaseClient):
         Domain: str,
         Name: str,
         AppMonitorConfiguration: AppMonitorConfigurationTypeDef = ...,
+        CustomEvents: CustomEventsTypeDef = ...,
         CwLogEnabled: bool = ...,
         Tags: Mapping[str, str] = ...
     ) -> CreateAppMonitorResponseTypeDef:
@@ -313,6 +315,7 @@ class CloudWatchRUMClient(BaseClient):
         *,
         Name: str,
         AppMonitorConfiguration: AppMonitorConfigurationTypeDef = ...,
+        CustomEvents: CustomEventsTypeDef = ...,
         CwLogEnabled: bool = ...,
         Domain: str = ...
     ) -> Dict[str, Any]:
