@@ -21,6 +21,7 @@ else:
 
 __all__ = (
     "BatchGetRumMetricDefinitionsPaginatorName",
+    "CustomEventsStatusType",
     "GetAppMonitorDataPaginatorName",
     "ListAppMonitorsPaginatorName",
     "ListRumMetricsDestinationsPaginatorName",
@@ -36,6 +37,7 @@ __all__ = (
 
 
 BatchGetRumMetricDefinitionsPaginatorName = Literal["batch_get_rum_metric_definitions"]
+CustomEventsStatusType = Literal["DISABLED", "ENABLED"]
 GetAppMonitorDataPaginatorName = Literal["get_app_monitor_data"]
 ListAppMonitorsPaginatorName = Literal["list_app_monitors"]
 ListRumMetricsDestinationsPaginatorName = Literal["list_rum_metrics_destinations"]
@@ -291,6 +293,7 @@ ServiceName = Literal[
     "redshift-serverless",
     "rekognition",
     "resiliencehub",
+    "resource-explorer-2",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -311,6 +314,7 @@ ServiceName = Literal[
     "sagemaker-featurestore-runtime",
     "sagemaker-runtime",
     "savingsplans",
+    "scheduler",
     "schemas",
     "sdb",
     "secretsmanager",
@@ -333,6 +337,7 @@ ServiceName = Literal[
     "ssm",
     "ssm-contacts",
     "ssm-incidents",
+    "ssmsap",
     "sso",
     "sso-admin",
     "sso-oidc",
