@@ -15,7 +15,7 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence, Union
 
-from .literals import MetricDestinationType, StateEnumType, TelemetryType
+from .literals import CustomEventsStatusType, MetricDestinationType, StateEnumType, TelemetryType
 
 if sys.version_info >= (3, 9):
     from typing import TypedDict
@@ -27,6 +27,7 @@ __all__ = (
     "AppMonitorConfigurationTypeDef",
     "AppMonitorDetailsTypeDef",
     "AppMonitorSummaryTypeDef",
+    "CustomEventsTypeDef",
     "MetricDefinitionRequestTypeDef",
     "MetricDefinitionTypeDef",
     "ResponseMetadataTypeDef",
@@ -111,6 +112,14 @@ AppMonitorSummaryTypeDef = TypedDict(
     total=False,
 )
 
+CustomEventsTypeDef = TypedDict(
+    "CustomEventsTypeDef",
+    {
+        "Status": CustomEventsStatusType,
+    },
+    total=False,
+)
+
 _RequiredMetricDefinitionRequestTypeDef = TypedDict(
     "_RequiredMetricDefinitionRequestTypeDef",
     {
@@ -442,6 +451,7 @@ _OptionalCreateAppMonitorRequestRequestTypeDef = TypedDict(
     "_OptionalCreateAppMonitorRequestRequestTypeDef",
     {
         "AppMonitorConfiguration": AppMonitorConfigurationTypeDef,
+        "CustomEvents": CustomEventsTypeDef,
         "CwLogEnabled": bool,
         "Tags": Mapping[str, str],
     },
@@ -465,6 +475,7 @@ _OptionalUpdateAppMonitorRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateAppMonitorRequestRequestTypeDef",
     {
         "AppMonitorConfiguration": AppMonitorConfigurationTypeDef,
+        "CustomEvents": CustomEventsTypeDef,
         "CwLogEnabled": bool,
         "Domain": str,
     },
@@ -733,6 +744,7 @@ AppMonitorTypeDef = TypedDict(
     {
         "AppMonitorConfiguration": AppMonitorConfigurationTypeDef,
         "Created": str,
+        "CustomEvents": CustomEventsTypeDef,
         "DataStorage": DataStorageTypeDef,
         "Domain": str,
         "Id": str,
